==> estateplat-common-1.2.3-20180505.051656-75-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtConfig.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * .
 * <p/>
 * 系统配置对象
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-19
 */
@Table(name = "bdc_xt_config")
public class BdcXtConfig {
    @Id
    //主键
    private String xtid;
    //年份
    private String nf;
    //单位代码
    private String dwdm;
    //权利类型
    private String qllx;
    //不动产权证号
    private String bdcqzh;
    //不动产权证号位数
    private Integer bdcqzhws;
    //登记机构
    private String djjg;
    //登记机构电话
    private String djjgdh;
    //省区市简称
    private String sqsjc;
    //所在市县全称
    private String szsxqc;
    //省区代码
    private String sqdm;


    public String getXtid() {
        return xtid;
    }

    public void setXtid(String xtid) {
        this.xtid = xtid;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public Integer getBdcqzhws() {
        return bdcqzhws;
    }

    public void setBdcqzhws(Integer bdcqzhws) {
        this.bdcqzhws = bdcqzhws;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getSqsjc() {
        return sqsjc;
    }

    public void setSqsjc(String sqsjc) {
        this.sqsjc = sqsjc;
    }

    public String getSzsxqc() {
        return szsxqc;
    }

    public void setSzsxqc(String szsxqc) {
        this.szsxqc = szsxqc;
    }

    public String getSqdm() {
        return sqdm;
    }

    public void setSqdm(String sqdm) {
        this.sqdm = sqdm;
    }

    public String getDjjgdh() {
        return djjgdh;
    }

    public void setDjjgdh(String djjgdh) {
        this.djjgdh = djjgdh;
    }
}

==> estateplat-common-1.2.4-20231220.022750-1206-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtConfig.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * .
 * <p/>
 * 系统配置对象
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-19
 */
@Table(name = "bdc_xt_config")
public class BdcXtConfig {
    @Id
    //主键
    private String xtid;
    //年份
    private String nf;
    //单位代码
    private String dwdm;
    //权利类型
    private String qllx;
    //不动产权证号
    private String bdcqzh;
    //不动产权证号位数
    private Integer bdcqzhws;
    //登记机构
    private String djjg;
    //登记机构电话
    private String djjgdh;
    //省区市简称
    private String sqsjc;
    //所在市县全称
    private String szsxqc;
    //省区代码
    private String sqdm;
    //启用时间
    private Date qysj;


    public String getXtid() {
        return xtid;
    }

    public void setXtid(String xtid) {
        this.xtid = xtid;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public Integer getBdcqzhws() {
        return bdcqzhws;
    }

    public void setBdcqzhws(Integer bdcqzhws) {
        this.bdcqzhws = bdcqzhws;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getSqsjc() {
        return sqsjc;
    }

    public void setSqsjc(String sqsjc) {
        this.sqsjc = sqsjc;
    }

    public String getSzsxqc() {
        return szsxqc;
    }

    public void setSzsxqc(String szsxqc) {
        this.szsxqc = szsxqc;
    }

    public String getSqdm() {
        return sqdm;
    }

    public void setSqdm(String sqdm) {
        this.sqdm = sqdm;
    }

    public String getDjjgdh() {
        return djjgdh;
    }

    public void setDjjgdh(String djjgdh) {
        this.djjgdh = djjgdh;
    }

    public Date getQysj() {
        return qysj;
    }

    public void setQysj(Date qysj) {
        this.qysj = qysj;
    }
}
